@@ -1,269 +1,314 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi">
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="17"/>
-        <location filename="mainwindow.cpp" line="75"/>
-        <location filename="ui_mainwindow.h" line="332"/>
+        <location filename="mainwindow.cpp" line="74"/>
+        <location filename="ui_mainwindow.h" line="289"/>
         <source>Repo Manager</source>
         <translation>पैकेज-संग्रह प्रबंधक</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="32"/>
-        <location filename="mainwindow.cpp" line="487"/>
-        <location filename="ui_mainwindow.h" line="333"/>
+        <location filename="mainwindow.cpp" line="627"/>
+        <location filename="ui_mainwindow.h" line="290"/>
         <source>Select the APT repository that you want to use:</source>
         <translation>उपयोग हेतु APT पैकेज-संग्रह चुनें :</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="59"/>
-        <location filename="ui_mainwindow.h" line="337"/>
+        <location filename="ui_mainwindow.h" line="294"/>
         <source>antiX repos</source>
         <translation>एंटीएक्स पैकेज-संग्रह</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="84"/>
-        <location filename="ui_mainwindow.h" line="334"/>
+        <location filename="ui_mainwindow.h" line="291"/>
         <source>Select fastest antiX repo for me</source>
         <translation>तीव्रतम एंटीएक्स पैकेज-संग्रह चुनें</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="114"/>
-        <location filename="ui_mainwindow.h" line="336"/>
+        <location filename="mainwindow.ui" line="110"/>
+        <location filename="ui_mainwindow.h" line="293"/>
         <source>search</source>
         <translation>खोजें</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="172"/>
-        <location filename="ui_mainwindow.h" line="339"/>
+        <location filename="mainwindow.ui" line="168"/>
+        <location filename="ui_mainwindow.h" line="296"/>
         <source>Debian repos</source>
         <translation>डेबियन पैकेज-संग्रह</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="184"/>
-        <location filename="ui_mainwindow.h" line="338"/>
+        <location filename="mainwindow.ui" line="180"/>
+        <location filename="ui_mainwindow.h" line="295"/>
         <source>Select fastest Debian repo for me</source>
         <translation>तीव्रतम डेबियन पैकेज-संग्रह चुनें</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="237"/>
-        <location filename="ui_mainwindow.h" line="341"/>
+        <location filename="mainwindow.ui" line="229"/>
+        <location filename="ui_mainwindow.h" line="298"/>
         <source>Individual sources</source>
         <translation>एकल स्रोत</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="256"/>
-        <location filename="ui_mainwindow.h" line="340"/>
+        <location filename="mainwindow.ui" line="248"/>
+        <location filename="ui_mainwindow.h" line="297"/>
         <source>Restore original APT sources</source>
         <translation>मूल APT स्रोत पुनः स्थापित करें</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="338"/>
-        <location filename="ui_mainwindow.h" line="343"/>
+        <location filename="mainwindow.ui" line="329"/>
+        <location filename="ui_mainwindow.h" line="300"/>
         <source>Display help </source>
         <translation>सहायता देखें</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="341"/>
-        <location filename="ui_mainwindow.h" line="345"/>
+        <location filename="mainwindow.ui" line="332"/>
+        <location filename="ui_mainwindow.h" line="302"/>
         <source>Help</source>
         <translation>सहायता</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="348"/>
-        <location filename="ui_mainwindow.h" line="346"/>
+        <location filename="mainwindow.ui" line="338"/>
+        <location filename="ui_mainwindow.h" line="304"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="393"/>
-        <location filename="ui_mainwindow.h" line="348"/>
+        <location filename="mainwindow.ui" line="383"/>
+        <location filename="ui_mainwindow.h" line="307"/>
         <source>About this application</source>
         <translation>इस अनुप्रयोग के बारे में</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="396"/>
-        <location filename="ui_mainwindow.h" line="350"/>
+        <location filename="mainwindow.ui" line="386"/>
+        <location filename="ui_mainwindow.h" line="309"/>
         <source>About...</source>
         <translation>बारे में...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="403"/>
-        <location filename="ui_mainwindow.h" line="351"/>
+        <location filename="mainwindow.ui" line="392"/>
+        <location filename="ui_mainwindow.h" line="311"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="419"/>
-        <location filename="ui_mainwindow.h" line="353"/>
+        <location filename="mainwindow.ui" line="408"/>
+        <location filename="ui_mainwindow.h" line="314"/>
         <source>Quit application</source>
         <translation>अनुप्रयोग बंद करें</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="422"/>
-        <location filename="ui_mainwindow.h" line="355"/>
+        <location filename="mainwindow.ui" line="411"/>
+        <location filename="ui_mainwindow.h" line="316"/>
         <source>Close</source>
         <translation>बंद करें</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="429"/>
-        <location filename="ui_mainwindow.h" line="356"/>
+        <location filename="mainwindow.ui" line="417"/>
+        <location filename="ui_mainwindow.h" line="318"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="448"/>
-        <location filename="ui_mainwindow.h" line="357"/>
+        <location filename="mainwindow.ui" line="436"/>
+        <location filename="ui_mainwindow.h" line="320"/>
         <source>Apply</source>
         <translation>लागू करें</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="62"/>
-        <source>Cancel</source>
-        <translation>रद्द करें</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="67"/>
-        <source>Please wait...</source>
-        <translation>प्रतीक्षा करें...</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="128"/>
-        <location filename="mainwindow.cpp" line="356"/>
-        <location filename="mainwindow.cpp" line="608"/>
+        <location filename="mainwindow.cpp" line="167"/>
+        <location filename="mainwindow.cpp" line="479"/>
+        <location filename="mainwindow.cpp" line="768"/>
         <source>Success</source>
         <translation>सफल</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="129"/>
-        <location filename="mainwindow.cpp" line="357"/>
-        <location filename="mainwindow.cpp" line="610"/>
+        <location filename="mainwindow.cpp" line="168"/>
+        <location filename="mainwindow.cpp" line="479"/>
+        <location filename="mainwindow.cpp" line="772"/>
         <source>Your new selection will take effect the next time sources are updated.</source>
         <translation>आप द्वारा किया गया नवीन चयन स्रोत अपडेट होने के उपरांत लागू होगा।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="201"/>
+        <location filename="mainwindow.cpp" line="305"/>
         <source>Lists</source>
         <translation>सूचियाँ</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="201"/>
+        <location filename="mainwindow.cpp" line="305"/>
         <source>Sources (checked sources are enabled)</source>
         <translation>स्रोत (चयनित स्रोत सक्रिय हैं)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="359"/>
-        <location filename="mainwindow.cpp" line="537"/>
-        <location filename="mainwindow.cpp" line="548"/>
-        <location filename="mainwindow.cpp" line="566"/>
-        <location filename="mainwindow.cpp" line="594"/>
+        <location filename="mainwindow.cpp" line="480"/>
+        <location filename="mainwindow.cpp" line="682"/>
+        <location filename="mainwindow.cpp" line="692"/>
+        <location filename="mainwindow.cpp" line="709"/>
+        <location filename="mainwindow.cpp" line="722"/>
+        <location filename="mainwindow.cpp" line="729"/>
+        <location filename="mainwindow.cpp" line="746"/>
+        <location filename="mainwindow.cpp" line="752"/>
+        <location filename="mainwindow.cpp" line="840"/>
         <source>Error</source>
         <translation>त्रुटि</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="360"/>
+        <location filename="mainwindow.cpp" line="480"/>
         <source>Could not change the repo.</source>
         <translation>पैकेज-संग्रह बदलना विफल।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="402"/>
-        <source>About %1</source>
-        <translation>%1 के बारे में</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="403"/>
-        <source>Version: </source>
-        <translation>संस्करण :</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="404"/>
-        <source>Program for choosing the default APT repository</source>
-        <translation>डिफ़ॉल्ट APT पैकेज-संग्रह चयन हेतु साधन</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="406"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation>कॉपीराइट (c) एमएक्स लिनक्स</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="407"/>
-        <source>%1 License</source>
-        <translation>%1 लाइसेंस</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="422"/>
-        <source>%1 Help</source>
-        <translation>%1 सहायता</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="430"/>
-        <source>Warning</source>
-        <translation>चेतावनी</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="431"/>
-        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
-        <translation>एमएक्स परीक्षण पैकेज-संग्रह चयनित है। इसे सक्रिय या इस द्वारा पैकेज अपग्रेड न करें।</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="432"/>
-        <source>A safer option is to install packages individually with MX Package Installer.</source>
-        <translation>इसके स्थान पर एमएक्स पैकेज इंस्टॉलर से एकल रूप से पैकेज इंस्टॉल करें।</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="489"/>
-        <source>Select the APT repository and sources that you want to use:</source>
-        <translation>उपयोग हेतु APT पैकेज-संग्रह व स्रोत चुनें :</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="538"/>
-        <source>netselect-apt could not detect fastest repo.</source>
-        <translation>netselect-apt द्वारा तीव्रतम पैकेज-संग्रह चयन विफल।</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="549"/>
-        <location filename="mainwindow.cpp" line="567"/>
-        <source>Could not detect fastest repo.</source>
-        <translation>तीव्रतम पैकेज-संग्रह चयन विफल।</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="595"/>
-        <source>Could not download original APT files.</source>
-        <translation>मूल APT फाइल डाउनलोड विफल।</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="609"/>
-        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
-        <translation>मूल स्रोतों की अपनी प्रकाशन स्थिति अनुरूप पुनः स्थापना सफल। /etc/apt/sources.list.d/ में उपस्थित उपयोक्ता द्वारा जोड़ी गई फाइलों में कोई परिवर्तन नहीं किया गया।</translation>
-    </message>
-</context>
-<context>
-    <name>QApplication</name>
-    <message>
-        <location filename="about.cpp" line="32"/>
-        <source>License</source>
-        <translation>लाइसेंस</translation>
-    </message>
-    <message>
-        <location filename="about.cpp" line="33"/>
-        <location filename="about.cpp" line="43"/>
-        <source>Changelog</source>
-        <translation>परिवर्तन सूची</translation>
-    </message>
-    <message>
-        <location filename="about.cpp" line="34"/>
+        <location filename="mainwindow.cpp" line="503"/>
         <source>Cancel</source>
         <translation>रद्द करें</translation>
     </message>
     <message>
-        <location filename="about.cpp" line="51"/>
-        <source>&amp;Close</source>
-        <translation>&amp;बंद करें</translation>
+        <location filename="mainwindow.cpp" line="509"/>
+        <source>Please wait...</source>
+        <translation>प्रतीक्षा करें...</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="53"/>
-        <source>You must run this program as root.</source>
-        <translation>इस प्रोग्राम को चलाने हेतु आपका रुट होना आवश्यक है।</translation>
+        <location filename="mainwindow.cpp" line="562"/>
+        <source>About %1</source>
+        <translation>%1 के बारे में</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="563"/>
+        <source>Version: </source>
+        <translation>संस्करण :</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="565"/>
+        <source>Program for choosing the default APT repository</source>
+        <translation>डिफ़ॉल्ट APT पैकेज-संग्रह चयन हेतु साधन</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="567"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation>कॉपीराइट (c) एमएक्स लिनक्स</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="568"/>
+        <source>%1 License</source>
+        <translation>%1 लाइसेंस</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="582"/>
+        <source>%1 Help</source>
+        <translation>%1 सहायता</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="591"/>
+        <source>Warning</source>
+        <translation>चेतावनी</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="592"/>
+        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
+        <translation>एमएक्स परीक्षण पैकेज-संग्रह चयनित है। इसे सक्रिय या इस द्वारा पैकेज अपग्रेड न करें।</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="595"/>
+        <source>A safer option is to install packages individually with MX Package Installer.</source>
+        <translation>इसके स्थान पर एमएक्स पैकेज इंस्टॉलर से एकल रूप से पैकेज इंस्टॉल करें।</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="629"/>
+        <source>Select the APT repository and sources that you want to use:</source>
+        <translation>उपयोग हेतु APT पैकेज-संग्रह व स्रोत चुनें :</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="682"/>
+        <source>netselect-apt could not detect fastest repo.</source>
+        <translation>netselect-apt द्वारा तीव्रतम पैकेज-संग्रह चयन विफल।</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="692"/>
+        <location filename="mainwindow.cpp" line="709"/>
+        <source>Could not detect fastest repo.</source>
+        <translation>तीव्रतम पैकेज-संग्रह चयन विफल।</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="722"/>
+        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="730"/>
+        <source>MX version not detected or out of range: </source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="746"/>
+        <source>Could not download original APT files.</source>
+        <translation>मूल APT फाइल डाउनलोड विफल।</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="752"/>
+        <source>Could not unzip downloaded file.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="763"/>
+        <source>Enabling AHS</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="763"/>
+        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="769"/>
+        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
+        <translation>मूल स्रोतों की अपनी प्रकाशन स्थिति अनुरूप पुनः स्थापना सफल। /etc/apt/sources.list.d/ में उपस्थित उपयोक्ता द्वारा जोड़ी गई फाइलों में कोई परिवर्तन नहीं किया गया।</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="841"/>
+        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="about.cpp" line="49"/>
+        <source>License</source>
+        <translation>लाइसेंस</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="50"/>
+        <location filename="about.cpp" line="60"/>
+        <source>Changelog</source>
+        <translation>बदलाव सूची</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="51"/>
+        <source>Cancel</source>
+        <translation>रद्द करें</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="73"/>
+        <source>&amp;Close</source>
+        <translation>बंद करें (&amp;C)</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="73"/>
+        <location filename="main.cpp" line="82"/>
+        <source>Error</source>
+        <translation>त्रुटि</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="74"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation>प्रतीत होता है कि आप रुट के रूप में लॉगिन हैं, प्रोग्राम उपयोग करने हेतु लॉगआउट कर सामान्य उपयोक्ता के रूप में लॉगिन करें।</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="83"/>
+        <source>You must run this program with admin access.</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
